==> apache-plc4x-0.9.1-source-release.zip: apache-plc4x-0.9.1/plc4j/utils/test-utils/src/main/java/org/apache/plc4x/test/parserserializer/model/ParserSerializerTestsuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.plc4x.test.parserserializer.model;

import java.util.List;
import java.util.Map;

public class ParserSerializerTestsuite {

    private final String name;
    private final List<Testcase> testcases;
    private final boolean littleEndian;
    private final Map<String, String> options;

    public ParserSerializerTestsuite(String name, List<Testcase> testcases, boolean littleEndian, Map<String, String> options) {
        this.name = name;
        this.testcases = testcases;
        this.littleEndian = littleEndian;
        this.options = options;
    }

    public String getName() {
        return name;
    }

    public List<Testcase> getTestcases() {
        return testcases;
    }

    public boolean isLittleEndian() {
        return littleEndian;
    }

    public Map<String, String> getOptions() {
        return options;
    }

}

==> apache-plc4x-0.13.1-source-release.zip: apache-plc4x-0.13.1/plc4j/utils/test-utils/src/main/java/org/apache/plc4x/test/parserserializer/model/ParserSerializerTestsuite.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.plc4x.test.parserserializer.model;

import org.apache.plc4x.java.spi.generation.ByteOrder;

import java.util.List;
import java.util.Map;

public class ParserSerializerTestsuite {

    private final String name;
    private final List<Testcase> testcases;
    private final ByteOrder byteOrder;
    private final Map<String, String> options;

    public ParserSerializerTestsuite(String name, List<Testcase> testcases, ByteOrder byteOrder, Map<String, String> options) {
        this.name = name;
        this.testcases = testcases;
        this.byteOrder = byteOrder;
        this.options = options;
    }

    public String getName() {
        return name;
    }

    public List<Testcase> getTestcases() {
        return testcases;
    }

    public ByteOrder getByteOrder() {
        return byteOrder;
    }

    public Map<String, String> getOptions() {
        return options;
    }

}
